#load packages
library("phyloseq")
library(ggplot2)

#set working directory

setwd("~/Desktop/Parks16S/USEARCH")

#load any file with the 16S USEARCH OTU table produced by USEARCH, or a phyloseq object that contains an OTU table. Metadata and taxonomy can be useful to have for some of the metrics below.
load("~/Desktop/Parks16S/USEARCH/parks16Susearch2304.Rda") 

#prune out controls - not used for BPS stats
ps.s = subset_samples(ps, All.controls == "Sample") 


#calculate total reads through pipeline
library(matrixStats)
readspersample <- sample_sums(otu_table(ps.s))
totalreads <- sum2(readspersample) #754752

#calculate mean reads/sample through the pipeline

mean(readspersample) #10938
sd(readspersample) #9381

#total ASVs
noasvs <- ntaxa(ps.s) #4400

#calculate mean OTUs/sample
asv_df <- (otu_table(ps.s))
ASVnos <- colSums(asv_df != 0)
mean(ASVnos) #315

#samples with no reads making it through pipeline
sampleswreads <- count(readspersample,idxs=NULL, value= 0) #0

#plot of total reads
library(data.table)

sdt = data.table(as(sample_data(ps.s), "data.frame"),
                 TotalReads = sample_sums(ps.s), keep.rownames = TRUE)
setnames(sdt, "rn", "SampleID")
pSeqDepth = ggplot(sdt, aes(TotalReads)) + geom_histogram() + ggtitle("Sequencing Depth")
pSeqDepth

#for a breakdown by sample category (eg location for Parks) - won't run without sample metadata
#ID sample variables for manipulation

pSeqDepth + facet_wrap(~Location)

#alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 

pAlpha = plot_richness(ps.s,
                       shape = "Control.type",
                       color = "Location",
                       measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                       title = "Alpha Diveristy")
pAlpha + geom_point(size = 5)

#Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.

# Store as a new data variable
alphadt = data.table(pAlpha$data)

#subset to just observed
alphadtO <- alphadt[(variable == "Observed")]
# Calc mean observed
meanobserved <- mean(alphadtO$value) #315
# Subset to just the Chao1 index
alphadtC <- alphadt[(variable == "Chao1")]
# Calc mean Chao1
meanChao1 <- mean(alphadtC$value) #373
#subset to just Shannon
alphadtS <- alphadt[(variable == "Shannon")]
# Calc mean Shannon
meanshannon <- mean(alphadtS$value) #3.`17`
#Calc exp of Shannon (Hill no D1)
expshannon <- exp(meanshannon) #23.8
#subset to just inv simpson
alphadtI <- alphadt[(variable == "InvSimpson")]
library(dplyr)
alphadtI2 <- filter(alphadtI, value!= "Inf")#Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp <- mean(alphadtI2$value) #16.66

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#create new ps object without samples with no reads as it effects the bray-curtis matrix
ps.no0s <- prune_samples(sample_sums(ps.s)>=1, ps.s) 

#transpose OTU table
OTU.table <- t(otu_table(ps.s))

betadiversity <- vegdist(OTU.table, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversitydata <- as.matrix(betadiversity) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversitydata)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversitydata) #69
betadiversitydata<-t(matrix(t(betadiversitydata)[which(!is.na(betadiversitydata))],nrow=69,ncol=68)) #removes NAs from matrix

#Mean of distances
meanbetadiversity <- mean(betadiversitydata) #0.87

#Median of distances
medianbetadiversity <- median(betadiversitydata) #0.91

#range of distances
rangebetadiversity <- range(betadiversitydata) #0.13 - 1

#standard deviation of distances

sdbetadiversity <- sd(betadiversitydata) #0.15

#Abundance - differential abundance in phyloseq and DESeq2. As location is the most relevant variable for Parks, that is used for the differential abundance calculation. 
library(DESeq2)

ps.sub = subset_samples(ps.s, Location != "<NA>") #these will be extraction/PCR negatives - fine to take out as would be removed by decontamination anyway
otu_table(ps.sub) <- otu_table(ps.sub) + 1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
diagdds = phyloseq_to_deseq2(ps.sub, ~ Location)
diagdds2 = DESeq(diagdds, test="Wald", fitType="parametric")

#results table
res = results(diagdds2, cooksCutoff = FALSE)
alpha = 0.01
sigtab = res[which(res$padj < alpha), ]
sigtab = cbind(as(sigtab, "data.frame"), as(tax_table(ps.sub)[rownames(sigtab), ], "matrix"))
head(sigtab)
dim(sigtab) #180 12

#plot of results if desired

  theme_set(theme_bw())
  scale_fill_discrete <- function(palname = "Set1", ...) {
    scale_fill_brewer(palette = palname, ...)
  }
  # Phylum order
  x = tapply(sigtab$log2FoldChange, sigtab$Phylum, function(x) max(x))
  x = sort(x, TRUE)
  sigtab$Phylum = factor(as.character(sigtab$Phylum), levels=names(x))
  # Genus order
  x = tapply(sigtab$log2FoldChange, sigtab$Genus, function(x) max(x))
  x = sort(x, TRUE)
  sigtab$Genus = factor(as.character(sigtab$Genus), levels=names(x))
  ggplot(sigtab, aes(x=Genus, y=log2FoldChange, color=Phylum)) + geom_point(size=6) + 
    theme(axis.text.x = element_text(angle = -90, hjust = 0, vjust=0.5))
  #180 genus are significantially differentially abundant between sites

  #Save workspace
  
  save.image("~/Desktop/Parks16S/USEARCH/Parks16SUSEARCHASVBPSnocontrols.RData")

########################################  ###################################################################################################################################
#Calculate breakdown of indicators by Park for mann-whitney U test to test statistical significance of differences in stats between pipelines
  
  load("~/Desktop/Parks16S/USEARCH/Parks16SUSEARCHASVBPSnocontrols.RData")
  
  #filter samples by park, then run above on each park
  
  ps.s.AS <- subset_samples(ps.s, Location == "Aotea Square ") #needs a space at the end
  ps.s.CP <- subset_samples(ps.s, Location == "Cornwall Park") 
  ps.s.FF <- subset_samples(ps.s, Location == "Fijoa Forest")
  ps.s.KH <- subset_samples(ps.s, Location == "Keith Hay Park")
  ps.s.MA <- subset_samples(ps.s, Location == "Mt Albert Park")
  ps.s.ME <- subset_samples(ps.s, Location == "Mt Eden Domain")
  ps.s.RL <- subset_samples(ps.s, Location == "Rural location")
  ps.s.TM <- subset_samples(ps.s, Location == "The Museum")
  ps.s.WF <- subset_samples(ps.s, Location == "Warren Freer Park")
  ps.s.WS <- subset_samples(ps.s, Location == "Western Springs")
  ps.s.WP <- subset_samples(ps.s, Location == "Windmill Park")
  
  ################################Aotea Square ###################################################################################################################################
  #prune empty taxa
  ps.s.AS <- prune_taxa(taxa_sums(ps.s.AS) > 0, ps.s.AS)
  
  #calculate total reads through pipeline for Aotea square
  
  library(matrixStats)
  readspersample.AS <- sample_sums(otu_table(ps.s.AS))
  totalreads.AS <- sum2(readspersample.AS) #19189
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.AS <- mean(readspersample.AS) #3837.8
  SD.AS <- sd(readspersample.AS) #5418.22
  
  #total ASVs
  noasvs.AS <- ntaxa(ps.s.AS) #252  
  
  #calculate mean ASVs/sample
  asv_df.AS <- (otu_table(ps.s.AS))
  ASVnos.AS <- colSums(asv_df.AS != 0)
  meanASV.AS <- mean(ASVnos.AS) #67.6
  
  #samples with no reads making it through pipeline
  sampleswreads.AS <- count(readspersample.AS, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.AS = plot_richness(ps.s.AS,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.AS + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.AS = data.table(pAlpha.AS$data)
  
  #subset to just observed
  alphadtO.AS <- alphadt.AS[(variable == "Observed")]
  # Calc mean observed
  meanobserved.AS <- mean(alphadtO.AS$value) #67.6
  # Subset to just the Chao1 index
  alphadtC.AS <- alphadt.AS[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.AS <- mean(alphadtC.AS$value) #80.6
  #subset to just Shannon
  alphadtS.AS <- alphadt.AS[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.AS <- mean(alphadtS.AS$value) #2.2
  #Calc exp of Shannon (Hill no D1)
  expshannon.AS <- exp(meanshannon.AS) #9.0
  #subset to just inv simpson
  alphadtI.AS <- alphadt.AS[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.AS <- filter(alphadtI.AS, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.AS <- mean(alphadtI2.AS$value) #5.6
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.AS <- prune_samples(sample_sums(ps.s.AS)>=1, ps.s.AS) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.AS) <- t(otu_table(ps.no0s.AS)) #transpose table
  betadiversity.AS <- vegdist(otu_table(ps.no0s.AS), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.AS <- as.matrix(betadiversity.AS) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.AS)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.AS) #5
  betadiversitydata.AS<-t(matrix(t(betadiversitydata.AS)[which(!is.na(betadiversitydata.AS))],nrow=5,ncol=4)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.AS <- mean(betadiversitydata.AS) #0.84
  
  #Median of distances
  medianbetadiversity.AS <- median(betadiversitydata.AS) #0.88
  
  #Range of distances
  rangebetadiversity.AS <- range(betadiversitydata.AS) #0.356 - 0.999 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.AS <- sd(betadiversitydata.AS) #0.17
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.AS = subset_samples(ps.no0s.AS, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.AS) <- (otu_table(ps.sub.AS))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.AS)$Date <- as.Date(sample_data(ps.sub.AS)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.AS)$Time.window <- ifelse(sample_data(ps.sub.AS)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.AS = phyloseq_to_deseq2(ps.sub.AS, ~ Time.window)
  diagdds2.AS = DESeq(diagdds.AS, test="Wald", fitType="parametric") 
  
  #results table
  res.AS = results(diagdds2.AS, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.AS = res.AS[which(res.AS$padj < alpha), ]
  sigtab.AS = cbind(as(sigtab.AS, "data.frame"), as(tax_table(ps.sub.AS)[rownames(sigtab.AS), ], "matrix"))
  sigtab1.AS <- as.data.frame(sigtab.AS)
  dim(sigtab1.AS) #1 12 Error as tax table slot empty. This still works without it. No sig diff taxa in the example, see what the other locations are like and consider how to calculate and present this stastic
  diff.abun.AS <- nrow(sigtab1.AS) #1
  
  ################################Cornwall Park ####################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.CP <- prune_taxa(taxa_sums(ps.s.CP) > 0, ps.s.CP)
  
  #calculate total reads through pipeline for Cornwall park
  readspersample.CP <- sample_sums(otu_table(ps.s.CP))
  totalreads.CP <- sum2(readspersample.CP) #89866
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.CP <- mean(readspersample.CP) #14977.67
  SD.CP <- sd(readspersample.CP) #12655.79
  
  #total ASVs
  noasvs.CP <- ntaxa(ps.s.CP) #1931
  
  #calculate mean ASVs/sample
  asv_df.CP <- (otu_table(ps.s.CP))
  ASVnos.CP <- colSums(asv_df.CP != 0)
  meanASV.CP <- mean(ASVnos.CP) #463.8333
  
  #samples with no reads making it through pipeline
  sampleswreads.CP <- count(readspersample.CP, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.CP = plot_richness(ps.s.CP,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.CP + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.CP = data.table(pAlpha.CP$data)
  
  #subset to just observed
  alphadtO.CP <- alphadt.CP[(variable == "Observed")]
  # Calc mean observed
  meanobserved.CP <- mean(alphadtO.CP$value) #463.8333
  # Subset to just the Chao1 index
  alphadtC.CP <- alphadt.CP[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.CP <- mean(alphadtC.CP$value) #522.87
  #subset to just Shannon
  alphadtS.CP <- alphadt.CP[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.CP <- mean(alphadtS.CP$value) #3.6
  #Calc exp of Shannon (Hill no D1)
  expshannon.CP <- exp(meanshannon.CP) #35.9
  #subset to just inv simpson
  alphadtI.CP <- alphadt.CP[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.CP <- filter(alphadtI.CP, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.CP <- mean(alphadtI2.CP$value) #19.1
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.CP <- prune_samples(sample_sums(ps.s.CP)>=1, ps.s.CP) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.CP) <- t(otu_table(ps.no0s.CP)) #transpose table
  betadiversity.CP <- vegdist(otu_table(ps.no0s.CP), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.CP <- as.matrix(betadiversity.CP) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.CP)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.CP) #6
  betadiversitydata.CP<-t(matrix(t(betadiversitydata.CP)[which(!is.na(betadiversitydata.CP))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.CP <- mean(betadiversitydata.CP) #0.88
  
  #Median of distances
  medianbetadiversity.CP <- median(betadiversitydata.CP) #0.91
  
  #Range of distances
  rangebetadiversity.CP <- range(betadiversitydata.CP) #0.555 - 1 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.CP <- sd(betadiversitydata.CP) #0.13
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.CP = subset_samples(ps.no0s.CP, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.CP) <- (otu_table(ps.sub.CP))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.CP)$Date <- as.Date(sample_data(ps.sub.CP)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.CP)$Time.window <- ifelse(sample_data(ps.sub.CP)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.CP = phyloseq_to_deseq2(ps.sub.CP, ~ Time.window)
  diagdds2.CP = DESeq(diagdds.CP, test="Wald", fitType="parametric") 
  
  #results table
  res.CP = results(diagdds2.CP, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.CP = res.CP[which(res.CP$padj < alpha), ]
  sigtab.CP = cbind(as(sigtab.CP, "data.frame"), as(tax_table(ps.sub.CP)[rownames(sigtab.CP), ], "matrix"))
  sigtab1.CP <- as.data.frame(sigtab.CP)
  dim(sigtab1.CP) #2 12 Error as tax table slot empty. This still works without it. 
  diff.abun.CP <- nrow(sigtab1.CP) #2
  
  ################################Fijoa Forest #####################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.FF <- prune_taxa(taxa_sums(ps.s.FF) > 0, ps.s.FF)
  
  #calculate total reads through pipeline for Fijoa Forest
  readspersample.FF <- sample_sums(otu_table(ps.s.FF))
  totalreads.FF <- sum2(readspersample.FF) #40891
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.FF <- mean(readspersample.FF) #6815.167
  SD.FF <- sd(readspersample.FF) #4768.821
  
  #total ASVs
  noasvs.FF <- ntaxa(ps.s.FF) #1519
  
  #calculate mean ASVs/sample
  asv_df.FF <- (otu_table(ps.s.FF))
  ASVnos.FF <- colSums(asv_df.FF != 0)
  meanASV.FF <- mean(ASVnos.FF) #346.6667
  
  #samples with no reads making it through pipeline
  sampleswreads.FF <- count(readspersample.FF, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.FF = plot_richness(ps.s.FF,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.FF + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.FF = data.table(pAlpha.FF$data)
  
  #subset to just observed
  alphadtO.FF <- alphadt.FF[(variable == "Observed")]
  # Calc mean observed
  meanobserved.FF <- mean(alphadtO.FF$value) #346.666
  # Subset to just the Chao1 index
  alphadtC.FF <- alphadt.FF[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.FF <- mean(alphadtC.FF$value) #418.62
  #subset to just Shannon
  alphadtS.FF <- alphadt.FF[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.FF <- mean(alphadtS.FF$value) #3.7
  #Calc exp of Shannon (Hill no D1)
  expshannon.FF <- exp(meanshannon.FF) #39.5
  #subset to just inv simpson
  alphadtI.FF <- alphadt.FF[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.FF <- filter(alphadtI.FF, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.FF <- mean(alphadtI2.FF$value) #25.1
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.FF <- prune_samples(sample_sums(ps.s.FF)>=1, ps.s.FF) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.FF) <- t(otu_table(ps.no0s.FF)) #transpose table
  betadiversity.FF <- vegdist(otu_table(ps.no0s.FF), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.FF <- as.matrix(betadiversity.FF) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.FF)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.FF) #6
  betadiversitydata.FF<-t(matrix(t(betadiversitydata.FF)[which(!is.na(betadiversitydata.FF))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.FF <- mean(betadiversitydata.FF) #0.90
  
  #Median of distances
  medianbetadiversity.FF <- median(betadiversitydata.FF) #0.91
  
  #Range of distances
  rangebetadiversity.FF <- range(betadiversitydata.FF) #0.694 - 0.999 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.FF <- sd(betadiversitydata.FF) #0.09
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.FF = subset_samples(ps.no0s.FF, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.FF) <- (otu_table(ps.sub.FF))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.FF)$Date <- as.Date(sample_data(ps.sub.FF)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.FF)$Time.window <- ifelse(sample_data(ps.sub.FF)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.FF = phyloseq_to_deseq2(ps.sub.FF, ~ Time.window)
  diagdds2.FF = DESeq(diagdds.FF, test="Wald", fitType="parametric") 
  
  #results table
  res.FF = results(diagdds2.FF, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.FF = res.FF[which(res.FF$padj < alpha), ]
  sigtab.FF = cbind(as(sigtab.FF, "data.frame"), as(tax_table(ps.sub.FF)[rownames(sigtab.FF), ], "matrix"))
  sigtab1.FF <- as.data.frame(sigtab.FF)
  dim(sigtab1.FF) #1 12 Error as tax table slot empty. This still works without it. 
  diff.abun.FF <- nrow(sigtab1.FF) #1
  
  ################################Keith Hay Park ###################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.KH <- prune_taxa(taxa_sums(ps.s.KH) > 0, ps.s.KH)
  
  #calculate total reads through pipeline for Keith Hay Park
  readspersample.KH <- sample_sums(otu_table(ps.s.KH))
  totalreads.KH <- sum2(readspersample.KH) #86282
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.KH <- mean(readspersample.KH) #12326
  SD.KH <- sd(readspersample.KH) #8840.01
  
  #total ASVs
  noasvs.KH <- ntaxa(ps.s.KH) #1348
  
  #calculate mean ASVs/sample
  asv_df.KH <- (otu_table(ps.s.KH))
  ASVnos.KH <- colSums(asv_df.KH != 0)
  meanASV.KH <- mean(ASVnos.KH) #276.4286
  
  #samples with no reads making it through pipeline
  sampleswreads.KH <- count(readspersample.KH, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.KH = plot_richness(ps.s.KH,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.KH + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.KH = data.table(pAlpha.KH$data)
  
  #subset to just observed
  alphadtO.KH <- alphadt.KH[(variable == "Observed")]
  # Calc mean observed
  meanobserved.KH <- mean(alphadtO.KH$value) #276.4286
  # Subset to just the Chao1 index
  alphadtC.KH <- alphadt.KH[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.KH <- mean(alphadtC.KH$value) #342.15
  #subset to just Shannon
  alphadtS.KH <- alphadt.KH[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.KH <- mean(alphadtS.KH$value) #3.0
  #Calc exp of Shannon (Hill no D1)
  expshannon.KH <- exp(meanshannon.KH) #19.7
  #subset to just inv simpson
  alphadtI.KH <- alphadt.KH[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.KH <- filter(alphadtI.KH, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.KH <- mean(alphadtI2.KH$value) #8.7
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.KH <- prune_samples(sample_sums(ps.s.KH)>=1, ps.s.KH) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.KH) <- t(otu_table(ps.no0s.KH)) #transpose table
  betadiversity.KH <- vegdist(otu_table(ps.no0s.KH), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.KH <- as.matrix(betadiversity.KH) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.KH)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.KH) #7
  betadiversitydata.KH<-t(matrix(t(betadiversitydata.KH)[which(!is.na(betadiversitydata.KH))],nrow=7,ncol=6)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.KH <- mean(betadiversitydata.KH) #0.89
  
  #Median of distances
  medianbetadiversity.KH <- median(betadiversitydata.KH) #0.97
  
  #Range of distances
  rangebetadiversity.KH <- range(betadiversitydata.KH) #0.56 - 0.997 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.KH <- sd(betadiversitydata.KH) #0.14
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.KH = subset_samples(ps.no0s.KH, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.KH) <- (otu_table(ps.sub.KH))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.KH)$Date <- as.Date(sample_data(ps.sub.KH)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.KH)$Time.window <- ifelse(sample_data(ps.sub.KH)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.KH = phyloseq_to_deseq2(ps.sub.KH, ~ Time.window)
  diagdds2.KH = DESeq(diagdds.KH, test="Wald", fitType="parametric") 
  
  #results table
  res.KH = results(diagdds2.KH, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.KH = res.KH[which(res.KH$padj < alpha), ]
  sigtab.KH = cbind(as(sigtab.KH, "data.frame"), as(tax_table(ps.sub.KH)[rownames(sigtab.KH), ], "matrix"))
  sigtab1.KH <- as.data.frame(sigtab.KH)
  dim(sigtab1.KH) #6 12 Error as tax table slot empty. This still works without it. 
  diff.abun.KH <- nrow(sigtab1.KH) #6
  
  ################################Mt Albert Park ###################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.MA <- prune_taxa(taxa_sums(ps.s.MA) > 0, ps.s.MA)
  
  #calculate total reads through pipeline for Mt Albert Park
  readspersample.MA <- sample_sums(otu_table(ps.s.MA))
  totalreads.MA <- sum2(readspersample.MA) #64224
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.MA <- mean(readspersample.MA) #9174.857
  SD.MA <- sd(readspersample.MA) #4717.206
  
  #total ASVs
  noasvs.MA <- ntaxa(ps.s.MA) #1334
  
  #calculate mean ASVs/sample
  asv_df.MA <- (otu_table(ps.s.MA))
  ASVnos.MA <- colSums(asv_df.MA != 0)
  meanASV.MA <- mean(ASVnos.MA) #297.8571
  
  #samples with no reads making it through pipeline
  sampleswreads.MA <- count(readspersample.MA, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.MA = plot_richness(ps.s.MA,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.MA + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.MA = data.table(pAlpha.MA$data)
  
  #subset to just observed
  alphadtO.MA <- alphadt.MA[(variable == "Observed")]
  # Calc mean observed
  meanobserved.MA <- mean(alphadtO.MA$value) #297.8571
  # Subset to just the Chao1 index
  alphadtC.MA <- alphadt.MA[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.MA <- mean(alphadtC.MA$value) #377.116
  #subset to just Shannon
  alphadtS.MA <- alphadt.MA[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.MA <- mean(alphadtS.MA$value) #3.2
  #Calc exp of Shannon (Hill no D1)
  expshannon.MA <- exp(meanshannon.MA) #24.9
  #subset to just inv simpson
  alphadtI.MA <- alphadt.MA[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.MA <- filter(alphadtI.MA, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.MA <- mean(alphadtI2.MA$value) #12.9
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.MA <- prune_samples(sample_sums(ps.s.MA)>=1, ps.s.MA) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.MA) <- t(otu_table(ps.no0s.MA)) #transpose table
  betadiversity.MA <- vegdist(otu_table(ps.no0s.MA), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.MA <- as.matrix(betadiversity.MA) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.MA)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.MA) #7
  betadiversitydata.MA<-t(matrix(t(betadiversitydata.MA)[which(!is.na(betadiversitydata.MA))],nrow=7,ncol=6)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.MA <- mean(betadiversitydata.MA) #0.83
  
  #Median of distances
  medianbetadiversity.MA <- median(betadiversitydata.MA) #0.94
  
  #Range of distances
  rangebetadiversity.MA <- range(betadiversitydata.MA) #0.213 - 0.971 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.MA <- sd(betadiversitydata.MA) #0.20
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.MA = subset_samples(ps.no0s.MA, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.MA) <- (otu_table(ps.sub.MA))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.MA)$Date <- as.Date(sample_data(ps.sub.MA)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.MA)$Time.window <- ifelse(sample_data(ps.sub.MA)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.MA = phyloseq_to_deseq2(ps.sub.MA, ~ Time.window)
  diagdds2.MA = DESeq(diagdds.MA, test="Wald", fitType="parametric") 
  
  #results table
  res.MA = results(diagdds2.MA, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.MA = res.MA[which(res.MA$padj < alpha), ]
  sigtab.MA = cbind(as(sigtab.MA, "data.frame"), as(tax_table(ps.sub.MA)[rownames(sigtab.MA), ], "matrix"))
  sigtab1.MA <- as.data.frame(sigtab.MA)
  dim(sigtab1.MA) #5 12 Error as tax table slot empty. This still works without it. 
  diff.abun.MA <- nrow(sigtab1.MA) #5
  
  ################################Mount Eden Domain ################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.ME <- prune_taxa(taxa_sums(ps.s.ME) > 0, ps.s.ME)
  
  #calculate total reads through pipeline for Mount Eden Domain
  readspersample.ME <- sample_sums(otu_table(ps.s.ME))
  totalreads.ME <- sum2(readspersample.ME) #70973
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.ME <- mean(readspersample.ME) #11828.83
  SD.ME <- sd(readspersample.ME) #9532.794
  
  #total ASVs
  noasvs.ME <- ntaxa(ps.s.ME) #1468
  
  #calculate mean ASVs/sample
  asv_df.ME <- (otu_table(ps.s.ME))
  ASVnos.ME <- colSums(asv_df.ME != 0)
  meanASV.ME <- mean(ASVnos.ME) #353.5
  
  #samples with no reads making it through pipeline
  sampleswreads.ME <- count(readspersample.ME, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.ME = plot_richness(ps.s.ME,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.ME + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.ME = data.table(pAlpha.ME$data)
  
  #subset to just observed
  alphadtO.ME <- alphadt.ME[(variable == "Observed")]
  # Calc mean observed
  meanobserved.ME <- mean(alphadtO.ME$value) #353.5
  # Subset to just the Chao1 index
  alphadtC.ME <- alphadt.ME[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.ME <- mean(alphadtC.ME$value) #397.83
  #subset to just Shannon
  alphadtS.ME <- alphadt.ME[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.ME <- mean(alphadtS.ME$value) #3.8
  #Calc exp of Shannon (Hill no D1)
  expshannon.ME <- exp(meanshannon.ME) #44.0
  #subset to just inv simpson
  alphadtI.ME <- alphadt.ME[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.ME <- filter(alphadtI.ME, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.ME <- mean(alphadtI2.ME$value) #16.9
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.ME <- prune_samples(sample_sums(ps.s.ME)>=1, ps.s.ME) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.ME) <- t(otu_table(ps.no0s.ME)) #transpose table
  betadiversity.ME <- vegdist(otu_table(ps.no0s.ME), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.ME <- as.matrix(betadiversity.ME) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.ME)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.ME) #6
  betadiversitydata.ME<-t(matrix(t(betadiversitydata.ME)[which(!is.na(betadiversitydata.ME))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.ME <- mean(betadiversitydata.ME) #0.86
  
  #Median of distances
  medianbetadiversity.ME <- median(betadiversitydata.ME) #0.85
  
  #Range of distances
  rangebetadiversity.ME <- range(betadiversitydata.ME) #0.736 - 0.939 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.ME <- sd(betadiversitydata.ME) #0.05
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.ME = subset_samples(ps.no0s.ME, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.ME) <- (otu_table(ps.sub.ME))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.ME)$Date <- as.Date(sample_data(ps.sub.ME)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.ME)$Time.window <- ifelse(sample_data(ps.sub.ME)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.ME = phyloseq_to_deseq2(ps.sub.ME, ~ Time.window)
  diagdds2.ME = DESeq(diagdds.ME, test="Wald", fitType="parametric") 
  
  #results table
  res.ME = results(diagdds2.ME, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.ME = res.ME[which(res.ME$padj < alpha), ]
  sigtab.ME = cbind(as(sigtab.ME, "data.frame"), as(tax_table(ps.sub.ME)[rownames(sigtab.ME), ], "matrix"))
  sigtab1.ME <- as.data.frame(sigtab.ME)
  dim(sigtab1.ME) #7 12 Error as tax table slot empty. This still works without it. 
  diff.abun.ME <- nrow(sigtab1.ME) #7
  
  ################################Rural location ###################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.RL <- prune_taxa(taxa_sums(ps.s.RL) > 0, ps.s.RL)
  
  #calculate total reads through pipeline for Mount Eden Domain
  readspersample.RL <- sample_sums(otu_table(ps.s.RL))
  totalreads.RL <- sum2(readspersample.RL) #75700
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.RL <- mean(readspersample.RL) #12616.67
  SD.RL <- sd(readspersample.RL) #13290.94
  
  #total ASVs
  noasvs.RL <- ntaxa(ps.s.RL) #1104
  
  #calculate mean ASVs/sample
  asv_df.RL <- (otu_table(ps.s.RL))
  ASVnos.RL <- colSums(asv_df.RL != 0)
  meanASV.RL <- mean(ASVnos.RL) #238.8333
  
  #samples with no reads making it through pipeline
  sampleswreads.RL <- count(readspersample.RL, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.RL = plot_richness(ps.s.RL,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.RL + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.RL = data.table(pAlpha.RL$data)
  
  #subset to just observed
  alphadtO.RL <- alphadt.RL[(variable == "Observed")]
  # Calc mean observed
  meanobserved.RL <- mean(alphadtO.RL$value) #238.8333
  # Subset to just the Chao1 index
  alphadtC.RL <- alphadt.RL[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.RL <- mean(alphadtC.RL$value) #269.76
  #subset to just Shannon
  alphadtS.RL <- alphadt.RL[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.RL <- mean(alphadtS.RL$value) #2.5
  #Calc exp of Shannon (Hill no D1)
  expshannon.RL <- exp(meanshannon.RL) #16.7
  #subset to just inv simpson
  alphadtI.RL <- alphadt.RL[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.RL <- filter(alphadtI.RL, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.RL <- mean(alphadtI2.RL$value) #6.8
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.RL <- prune_samples(sample_sums(ps.s.RL)>=1, ps.s.RL) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.RL) <- t(otu_table(ps.no0s.RL)) #transpose table
  betadiversity.RL <- vegdist(otu_table(ps.no0s.RL), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.RL <- as.matrix(betadiversity.RL) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.RL)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.RL) #6
  betadiversitydata.RL<-t(matrix(t(betadiversitydata.RL)[which(!is.na(betadiversitydata.RL))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.RL <- mean(betadiversitydata.RL) #0.91
  
  #Median of distances
  medianbetadiversity.RL <- median(betadiversitydata.RL) #0.92
  
  #Range of distances
  rangebetadiversity.RL <- range(betadiversitydata.RL) #0.521 - 1 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.RL <- sd(betadiversitydata.RL) #0.12
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.RL = subset_samples(ps.no0s.RL, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.RL) <- (otu_table(ps.sub.RL))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.RL)$Date <- as.Date(sample_data(ps.sub.RL)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.RL)$Time.window <- ifelse(sample_data(ps.sub.RL)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.RL = phyloseq_to_deseq2(ps.sub.RL, ~ Time.window)
  diagdds2.RL = DESeq(diagdds.RL, test="Wald", fitType="parametric") 
  
  #results table
  res.RL = results(diagdds2.RL, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.RL = res.RL[which(res.RL$padj < alpha), ]
  sigtab.RL = cbind(as(sigtab.RL, "data.frame"), as(tax_table(ps.sub.RL)[rownames(sigtab.RL), ], "matrix"))
  sigtab1.RL <- as.data.frame(sigtab.RL)
  dim(sigtab1.RL) #4 12 Error as tax table slot empty. This still works without it. 
  diff.abun.RL <- nrow(sigtab1.RL) #4
  
  ################################The Museum #####################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.TM <- prune_taxa(taxa_sums(ps.s.TM) > 0, ps.s.TM)
  
  #calculate total reads through pipeline for The Museum
  readspersample.TM <- sample_sums(otu_table(ps.s.TM))
  totalreads.TM <- sum2(readspersample.TM) #47295
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.TM <- mean(readspersample.TM) #7882.5
  SD.TM <- sd(readspersample.TM) #9754.312
  
  #total ASVs
  noasvs.TM <- ntaxa(ps.s.TM) #1265
  
  #calculate mean ASVs/sample
  asv_df.TM <- (otu_table(ps.s.TM))
  ASVnos.TM <- colSums(asv_df.TM != 0)
  meanASV.TM <- mean(ASVnos.TM) #264.5
  
  #samples with no reads making it through pipeline
  sampleswreads.TM <- count(readspersample.TM, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.TM = plot_richness(ps.s.TM,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.TM + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.TM = data.table(pAlpha.TM$data)
  
  #subset to just observed
  alphadtO.TM <- alphadt.TM[(variable == "Observed")]
  # Calc mean observed
  meanobserved.TM <- mean(alphadtO.TM$value) #264.5
  # Subset to just the Chao1 index
  alphadtC.TM <- alphadt.TM[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.TM <- mean(alphadtC.TM$value) #323.01
  #subset to just Shannon
  alphadtS.TM <- alphadt.TM[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.TM <- mean(alphadtS.TM$value) #2.4
  #Calc exp of Shannon (Hill no D1)
  expshannon.TM <- exp(meanshannon.TM) #11.4
  #subset to just inv simpson
  alphadtI.TM <- alphadt.TM[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.TM <- filter(alphadtI.TM, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.TM <- mean(alphadtI2.TM$value) #9.9
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.TM <- prune_samples(sample_sums(ps.s.TM)>=1, ps.s.TM) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.TM) <- t(otu_table(ps.no0s.TM)) #transpose table
  betadiversity.TM <- vegdist(otu_table(ps.no0s.TM), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.TM <- as.matrix(betadiversity.TM) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.TM)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.TM) #6
  betadiversitydata.TM<-t(matrix(t(betadiversitydata.TM)[which(!is.na(betadiversitydata.TM))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.TM <- mean(betadiversitydata.TM) #0.96
  
  #Median of distances
  medianbetadiversity.TM <- median(betadiversitydata.TM) #0.99
  
  #Range of distances
  rangebetadiversity.TM <- range(betadiversitydata.TM) #0.611 - 1 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.TM <- sd(betadiversitydata.TM) #0.10
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.TM = subset_samples(ps.no0s.TM, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.TM) <- (otu_table(ps.sub.TM))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.TM)$Date <- as.Date(sample_data(ps.sub.TM)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.TM)$Time.window <- ifelse(sample_data(ps.sub.TM)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.TM = phyloseq_to_deseq2(ps.sub.TM, ~ Time.window)
  diagdds2.TM = DESeq(diagdds.TM, test="Wald", fitType="parametric") 
  
  #results table
  res.TM = results(diagdds2.TM, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.TM = res.TM[which(res.TM$padj < alpha), ]
  sigtab.TM = cbind(as(sigtab.TM, "data.frame"), as(tax_table(ps.sub.TM)[rownames(sigtab.TM), ], "matrix"))
  sigtab1.TM <- as.data.frame(sigtab.TM)
  dim(sigtab1.TM) #10 12 Error as tax table slot empty. This still works without it. 
  diff.abun.TM <- nrow(sigtab1.TM) #10
  
  ################################Warren Freer Park ################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.WF <- prune_taxa(taxa_sums(ps.s.WF) > 0, ps.s.WF)
  
  #calculate total reads through pipeline for Warren Freer Park
  readspersample.WF <- sample_sums(otu_table(ps.s.WF))
  totalreads.WF <- sum2(readspersample.WF) #66416
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.WF <- mean(readspersample.WF) #9488
  SD.WF <- sd(readspersample.WF) #6824.48
  
  #total ASVs
  noasvs.WF <- ntaxa(ps.s.WF) #1104
  
  #calculate mean ASVs/sample
  asv_df.WF <- (otu_table(ps.s.WF))
  ASVnos.WF <- colSums(asv_df.WF != 0)
  meanASV.WF <- mean(ASVnos.WF) #225.14
  
  #samples with no reads making it through pipeline
  sampleswreads.WF <- count(readspersample.WF, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.WF = plot_richness(ps.s.WF,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.WF + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.WF = data.table(pAlpha.WF$data)
  
  #subset to just observed
  alphadtO.WF <- alphadt.WF[(variable == "Observed")]
  # Calc mean observed
  meanobserved.WF <- mean(alphadtO.WF$value) #225.14
  # Subset to just the Chao1 index
  alphadtC.WF <- alphadt.WF[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.WF <- mean(alphadtC.WF$value) #278.43
  #subset to just Shannon
  alphadtS.WF <- alphadt.WF[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.WF <- mean(alphadtS.WF$value) #3.2
  #Calc exp of Shannon (Hill no D1)
  expshannon.WF <- exp(meanshannon.WF) #23.8
  #subset to just inv simpson
  alphadtI.WF <- alphadt.WF[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.WF <- filter(alphadtI.WF, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.WF <- mean(alphadtI2.WF$value) #9.8
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.WF <- prune_samples(sample_sums(ps.s.WF)>=1, ps.s.WF) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.WF) <- t(otu_table(ps.no0s.WF)) #transpose table
  betadiversity.WF <- vegdist(otu_table(ps.no0s.WF), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.WF <- as.matrix(betadiversity.WF) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.WF)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.WF) #7
  betadiversitydata.WF<-t(matrix(t(betadiversitydata.WF)[which(!is.na(betadiversitydata.WF))],nrow=7,ncol=6)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.WF <- mean(betadiversitydata.WF) #0.73
  
  #Median of distances
  medianbetadiversity.WF <- median(betadiversitydata.WF) #0.72
  
  #Range of distances
  rangebetadiversity.WF <- range(betadiversitydata.WF) #0.468 - 0.954 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.WF <- sd(betadiversitydata.WF) #0.15
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.WF = subset_samples(ps.no0s.WF, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.WF) <- (otu_table(ps.sub.WF))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.WF)$Date <- as.Date(sample_data(ps.sub.WF)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.WF)$Time.window <- ifelse(sample_data(ps.sub.WF)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.WF = phyloseq_to_deseq2(ps.sub.WF, ~ Time.window)
  diagdds2.WF = DESeq(diagdds.WF, test="Wald", fitType="parametric") 
  
  #results table
  res.WF = results(diagdds2.WF, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.WF = res.WF[which(res.WF$padj < alpha), ]
  sigtab.WF = cbind(as(sigtab.WF, "data.frame"), as(tax_table(ps.sub.WF)[rownames(sigtab.WF), ], "matrix"))
  sigtab1.WF <- as.data.frame(sigtab.WF)
  dim(sigtab1.WF) #4 12 Error as tax table slot empty. This still works without it. N
  diff.abun.WF <- nrow(sigtab1.WF) #4
  
  ################################Western Springs ##################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.WS <- prune_taxa(taxa_sums(ps.s.WS) > 0, ps.s.WS)
  
  #calculate total reads through pipeline for Western Springs
  readspersample.WS <- sample_sums(otu_table(ps.s.WS))
  totalreads.WS <- sum2(readspersample.WS) #78917
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.WS <- mean(readspersample.WS) #13152.83
  SD.WS <- sd(readspersample.WS) #8342.14
  
  #total ASVs
  noasvs.WS <- ntaxa(ps.s.WS) #1857
  
  #calculate mean ASVs/sample
  asv_df.WS <- (otu_table(ps.s.WS))
  ASVnos.WS <- colSums(asv_df.WS != 0)
  meanASV.WS <- mean(ASVnos.WS) #485.8333
  
  #samples with no reads making it through pipeline
  sampleswreads.WS <- count(readspersample.WS, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.WS = plot_richness(ps.s.WS,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.WS + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.WS = data.table(pAlpha.WS$data)
  
  #subset to just observed
  alphadtO.WS <- alphadt.WS[(variable == "Observed")]
  # Calc mean observed
  meanobserved.WS <- mean(alphadtO.WS$value) #485.8333
  # Subset to just the Chao1 index
  alphadtC.WS <- alphadt.WS[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.WS <- mean(alphadtC.WS$value) #567.85
  #subset to just Shannon
  alphadtS.WS <- alphadt.WS[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.WS <- mean(alphadtS.WS$value) #3.6
  #Calc exp of Shannon (Hill no D1)
  expshannon.WS <- exp(meanshannon.WS) #38.0
  #subset to just inv simpson
  alphadtI.WS <- alphadt.WS[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.WS <- filter(alphadtI.WS, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.WS <- mean(alphadtI2.WS$value) #11.1
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.WS <- prune_samples(sample_sums(ps.s.WS)>=1, ps.s.WS) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.WS) <- t(otu_table(ps.no0s.WS)) #transpose table
  betadiversity.WS <- vegdist(otu_table(ps.no0s.WS), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.WS <- as.matrix(betadiversity.WS) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.WS)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.WS) #6
  betadiversitydata.WS<-t(matrix(t(betadiversitydata.WS)[which(!is.na(betadiversitydata.WS))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.WS <- mean(betadiversitydata.WS) #0.82
  
  #Median of distances
  medianbetadiversity.WS <- median(betadiversitydata.WS) #0.82
  
  #Range of distances
  rangebetadiversity.WS <- range(betadiversitydata.WS) #0.508 - 0.982 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.WS <- sd(betadiversitydata.WS) #0.12
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.WS = subset_samples(ps.no0s.WS, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.WS) <- (otu_table(ps.sub.WS))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.WS)$Date <- as.Date(sample_data(ps.sub.WS)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.WS)$Time.window <- ifelse(sample_data(ps.sub.WS)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.WS = phyloseq_to_deseq2(ps.sub.WS, ~ Time.window)
  diagdds2.WS = DESeq(diagdds.WS, test="Wald", fitType="parametric") 
  
  #results table
  res.WS = results(diagdds2.WS, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.WS = res.WS[which(res.WS$padj < alpha), ]
  sigtab.WS = cbind(as(sigtab.WS, "data.frame"), as(tax_table(ps.sub.WS)[rownames(sigtab.WS), ], "matrix"))
  sigtab1.WS <- as.data.frame(sigtab.WS)
  dim(sigtab1.WS) #1 12 Error as tax table slot empty. This still works without it. 
  diff.abun.WS <- nrow(sigtab1.WS) #1
  
  ################################Windmill Park ####################################################################################################################################
  # Prune out out empty taxa (not removed on subsetting)
  ps.s.WP <- prune_taxa(taxa_sums(ps.s.WP) > 0, ps.s.WP)
  
  #calculate total reads through pipeline for Windmill Park
  readspersample.WP <- sample_sums(otu_table(ps.s.WP))
  totalreads.WP <- sum2(readspersample.WP) #100524
  
  #calculate mean reads/sample through the pipeline
  
  meanreadspersample.WP <- mean(readspersample.WP) #16754
  SD.WP <- sd(readspersample.WP) #14725.1
  
  #total ASVs
  noasvs.WP <- ntaxa(ps.s.WP) #1566
  
  #calculate mean ASVs/sample
  asv_df.WP <- (otu_table(ps.s.WP))
  ASVnos.WP <- colSums(asv_df.WP != 0)
  meanASV.WP <- mean(ASVnos.WP) #337.3333
  
  #samples with no reads making it through pipeline
  sampleswreads.WP <- count(readspersample.WP, idxs = NULL, value= 0) #0
  
  #alpha diversity - plot observed, shannon, chao1, inv simpson by location for example. 
  
  pAlpha.WP = plot_richness(ps.s.WP,
                            shape = "Control.type",
                            color = "Location",
                            measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                            title = "Alpha Diveristy")
  pAlpha.WP + geom_point(size = 5)
  
  #Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
  
  #Load data table package
  library(data.table)
  
  # Store as a new data variable
  alphadt.WP = data.table(pAlpha.WP$data)
  
  #subset to just observed
  alphadtO.WP <- alphadt.WP[(variable == "Observed")]
  # Calc mean observed
  meanobserved.WP <- mean(alphadtO.WP$value) #337.3333
  # Subset to just the Chao1 index
  alphadtC.WP <- alphadt.WP[(variable == "Chao1")]
  # Calc mean Chao1
  meanChao1.WP <- mean(alphadtC.WP$value) #385.9
  #subset to just Shannon
  alphadtS.WP <- alphadt.WP[(variable == "Shannon")]
  # Calc mean Shannon
  meanshannon.WP <- mean(alphadtS.WP$value) #3.1
  #Calc exp of Shannon (Hill no D1)
  expshannon.WP <- exp(meanshannon.WP) #21.4
  #subset to just inv simpson
  alphadtI.WP <- alphadt.WP[(variable == "InvSimpson")]
  library(dplyr)
  alphadtI2.WP <- filter(alphadtI.WP, value!= "Inf") #Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
  # Calc mean inv simpson
  meaninvsimp.WP <- mean(alphadtI2.WP$value) #15.5
  
  #Beta diversity (between sample variation) - Bray-curtis
  library(vegan)
  
  #create new ps object without samples with no reads as it effects the bray-curtis matrix
  ps.no0s.WP <- prune_samples(sample_sums(ps.s.WP)>=1, ps.s.WP) #prune samples without reads from phyloseq object
  otu_table(ps.no0s.WP) <- t(otu_table(ps.no0s.WP)) #transpose table
  betadiversity.WP <- vegdist(otu_table(ps.no0s.WP), method = "bray", upper= TRUE, diag=FALSE) #produces matix. 
  
  #Calculate desired metrics - from sums of all the distances in the (square) matrix
  betadiversitydata.WP <- as.matrix(betadiversity.WP) 
  
  #Remove 0s (from comparison to a site to itself) as they skew measures below
  diag(betadiversitydata.WP)=NA #adds NAs to diagonal (all 0 currently)
  nrow(betadiversitydata.WP) #6
  betadiversitydata.WP<-t(matrix(t(betadiversitydata.WP)[which(!is.na(betadiversitydata.WP))],nrow=6,ncol=5)) #removes NAs from matrix
  
  #Mean of distances
  meanbetadiversity.WP <- mean(betadiversitydata.WP) #0.91
  
  #Median of distances
  medianbetadiversity.WP <- median(betadiversitydata.WP) #0.92
  
  #Range of distances
  rangebetadiversity.WP <- range(betadiversitydata.WP) #0.73 - 1 - all the same, included for completeness
  
  #Standard deviation of distances
  
  sdbetadiversity.WP <- sd(betadiversitydata.WP) #0.09
  
  #Abundance - differential abundance in phyloseq and DESeq2. As all samples from one location only are now included, differential abundance is now performed by time as it cannot be done by sample
  library(DESeq2)
  
  ps.sub.WP = subset_samples(ps.no0s.WP, Location != "<NA>") #these will be extraction/PCR negative controls - fine to take out as would be removed by decontamination anyway
  otu_table(ps.sub.WP) <- (otu_table(ps.sub.WP))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistently for everything being compared.
  sample_data(ps.sub.WP)$Date <- as.Date(sample_data(ps.sub.WP)$Date, format = "%d/%m/%Y") #make date date format
  sample_data(ps.sub.WP)$Time.window <- ifelse(sample_data(ps.sub.WP)$Date<"2018-03-20", "Winter", "Autumn") #Add new column to categorise samples as summer and winter
  diagdds.WP = phyloseq_to_deseq2(ps.sub.WP, ~ Time.window)
  diagdds2.WP = DESeq(diagdds.WP, test="Wald", fitType="parametric") 
  
  #results table
  res.WP = results(diagdds2.WP, cooksCutoff = FALSE)
  alpha = 0.01
  sigtab.WP = res.WP[which(res.WP$padj < alpha), ]
  sigtab.WP = cbind(as(sigtab.WP, "data.frame"), as(tax_table(ps.sub.WP)[rownames(sigtab.WP), ], "matrix"))
  sigtab1.WP <- as.data.frame(sigtab.WP)
  dim(sigtab1.WP) #5 12 Error as tax table slot empty. This still works without it. 
  diff.abun.WP <- nrow(sigtab1.WP) #5
  
  ###############################################################################################################################################################################
  
  #save workspace
  
  save.image("~/Desktop/Parks16S/USEARCH/Parks16SUSEARCHASVBPSnocontrols080521.RData")
  
  #summary table
  
  #create matrix
  USEARCHASV16Ssummary.metrics <- matrix(c(totalreads.AS, totalreads.CP, totalreads.FF, totalreads.KH, totalreads.MA, totalreads.ME, totalreads.RL, totalreads.TM, totalreads.WF, totalreads.WS, totalreads.WP, meanreadspersample.AS, meanreadspersample.CP, meanreadspersample.FF, meanreadspersample.KH, meanreadspersample.MA, meanreadspersample.ME, meanreadspersample.RL, meanreadspersample.TM, meanreadspersample.WF, meanreadspersample.WS, meanreadspersample.WP, SD.AS, SD.CP, SD.FF, SD.KH, SD.MA, SD.ME, SD.RL, SD.TM, SD.WF, SD.WS, SD.WP, noasvs.AS, noasvs.CP, noasvs.FF, noasvs.KH, noasvs.MA, noasvs.ME, noasvs.RL, noasvs.TM, noasvs.WF, noasvs.WS, noasvs.WP, meanASV.AS, meanASV.CP, meanASV.FF, meanASV.KH, meanASV.MA, meanASV.ME, meanASV.RL, meanASV.TM, meanASV.WF, meanASV.WS, meanASV.WP, sampleswreads.AS, sampleswreads.CP, sampleswreads.FF, sampleswreads.KH, sampleswreads.MA, sampleswreads.ME, sampleswreads.RL, sampleswreads.TM, sampleswreads.WF, sampleswreads.WS, sampleswreads.WP, meanobserved.AS, meanobserved.CP, meanobserved.FF, meanobserved.KH, meanobserved.MA, meanobserved.ME, meanobserved.RL, meanobserved.TM, meanobserved.WF, meanobserved.WS, meanobserved.WP, meanChao1.AS, meanChao1.CP, meanChao1.FF, meanChao1.KH, meanChao1.MA, meanChao1.ME, meanChao1.RL, meanChao1.TM, meanChao1.WF, meanChao1.WS, meanChao1.WP, meanshannon.AS, meanshannon.CP, meanshannon.FF, meanshannon.KH, meanshannon.MA, meanshannon.ME, meanshannon.RL, meanshannon.TM, meanshannon.WF, meanshannon.WS, meanshannon.WP, expshannon.AS, expshannon.CP, expshannon.FF, expshannon.KH, expshannon.MA, expshannon.ME, expshannon.RL, expshannon.TM, expshannon.WF, expshannon.WS, expshannon.WP, meaninvsimp.AS, meaninvsimp.CP, meaninvsimp.FF, meaninvsimp.KH, meaninvsimp.MA, meaninvsimp.ME, meaninvsimp.RL, meaninvsimp.TM, meaninvsimp.WF, meaninvsimp.WS, meaninvsimp.WP, meanbetadiversity.AS, meanbetadiversity.CP, meanbetadiversity.FF, meanbetadiversity.KH, meanbetadiversity.MA, meanbetadiversity.ME, meanbetadiversity.RL, meanbetadiversity.TM, meanbetadiversity.WF, meanbetadiversity.WS, meanbetadiversity.WP, medianbetadiversity.AS, medianbetadiversity.CP, medianbetadiversity.FF, medianbetadiversity.KH, medianbetadiversity.MA, medianbetadiversity.ME, medianbetadiversity.RL, medianbetadiversity.TM, medianbetadiversity.WF, medianbetadiversity.WS, medianbetadiversity.WP, "0.356 - 0.999", "0.555 - 1", "0.694 - 1", "0.56 - 0.997", "0.213 - 0.971", "0.736 - 0.939", "0.521 - 1", "0.611 - 1", "0.468 - 0.954", "0.508 - 0.982", "0.73 - 1", sdbetadiversity.AS, sdbetadiversity.CP, sdbetadiversity.FF, sdbetadiversity.KH, sdbetadiversity.MA, sdbetadiversity.ME, sdbetadiversity.RL, sdbetadiversity.TM, sdbetadiversity.WF, sdbetadiversity.WS, sdbetadiversity.WP, diff.abun.AS, diff.abun.CP, diff.abun.FF, diff.abun.KH, diff.abun.MA, diff.abun.ME, diff.abun.RL, diff.abun.TM, diff.abun.WF, diff.abun.WS, diff.abun.WP), ncol=11, byrow=TRUE)
  
  #define column names and row names of matrix
  colnames(USEARCHASV16Ssummary.metrics) <- c('Aotea Square', 'Cornwall Park', 'Fijoa Forest', 'Keith Hay Park', 'Mt Albert Park', 'Mount Eden Domain', 'Rural location', 'The Museum', 'Warren Freer Park', 'Western Springs', 'Windmill Park')
  
  rownames(USEARCHASV16Ssummary.metrics) <- c('16S USEARCH ASVs - total reads', '16S USEARCH ASVs - mean reads per sample', '16S USEARCH ASVs - SD', '16S USEARCH ASVs - total ASVs', '16S USEARCH ASVs - mean ASVs per sample', '16S USEARCH ASVs - samples with no reads', '16S USEARCH ASVs - mean observed', '16S USEARCH ASVs - mean Chao1', '16S USEARCH ASVs - mean Shannon', '16S USEARCH ASVs - exp Shannon', '16S USEARCH ASVs - mean inv simpson', '16S USEARCH ASVs - mean beta diversity', '16S USEARCH ASVs - median beta diversity', '16S USEARCH ASVs - range beta diversity', '16S USEARCH ASVs - SD beta diversity', '16S USEARCH ASVs - differential abundance') #one row for each metric
  
  # Save an object in RData format
  save(USEARCHASV16Ssummary.metrics, file = "~/Desktop/Parks16S/USEARCH/USEARCHASV16Ssummary.RData")
  
  #save workspace
  
  save.image("~/Desktop/Parks16S/USEARCH/Parks16SUSEARCHASVBPSnocontrols080521.RData")
  