#Analysis of the differences between RDP and SILVA classifications for 16S USEARCH ASVs
library(phyloseq)

#Set working directory
setwd("~/Desktop/Parks16S/USEARCH")

#Load phyloseq with 16S USEARCH SILVA taxonomy (Uses USEARCH OTU codes)
load("PSUSEARCHPARKS16SRDP.Rda")
#Phyloseq with 16S USEARCH and RDP taxonomy (Uses USEARCH OTU codes)
load("PSUSEARCHPARKS16SSILVA.Rda")

#Go outside phyloseq - as only one tax table can be loaded into phyloseq
#Re-read in tax tables to ensure accuracy
library("RDPutils")
taxtab.SILVA <- as.data.frame(import_sintax_file("~/Desktop/Parks16S/USEARCHSILVA/16Ssintax_mod.txt", confidence = 0.8))
taxtab.RDP <- as.data.frame(import_sintax_file("sintax.txt", confidence = 0.8))

#rename cols so each DB can be distingushed later on

colnames(taxtab.SILVA) <- paste("SILVA", colnames(taxtab.SILVA), sep = "_")
colnames(taxtab.RDP) <- paste("RDP", colnames(taxtab.RDP), sep = "_")

#Pull out a list of the Genus in each dataset

RDPGenus <- taxtab.RDP$RDP_Genus #517 taxa correct
SILVAGenus <- taxtab.SILVA$SILVA_Genus #694 taxa correct

#Plot Venn Diag
library(VennDiagram)

venn.plot <- venn.diagram(
  x = list(
    "RDP Genera" = RDPGenus,
    "SILVA Genera" = SILVAGenus
  ),
  filename = "RDPvSILVAGenera16Sforpub.png",
  lwd = 4,
  fill = c("cornflowerblue", "darkorchid1"),
  alpha = 0.75,
  label.col = "deeppink3",
  cex = 3,
  imagetype = "png",
  fontfamily = "serif",
  fontface = "bold",
  cat.col = c("cornflowerblue", "darkorchid1"),
  cat.cex = 2,
  cat.fontfamily = "serif",
  cat.fontface = "bold",
  cat.dist = c(0.03, 0.03),
  cat.pos = c(-20, 14),
  resolution = 300
); #totals agree to above

#move ASV names into first column so they can be accessed by the join function
library(tibble)
taxtab.SILVA <- rownames_to_column(taxtab.SILVA, "ASV")
taxtab.RDP <- rownames_to_column(taxtab.RDP, "ASV")

#left join two files
library(dplyr)
tax.RDP.SILVA <- left_join(taxtab.SILVA, taxtab.RDP, by = "ASV")

#flag same or different classification at the Genus level - creates a new column "same" with true or false if the genus for each taxonomy database match.

library(tidyverse)
tax.RDP.SILVA <- tax.RDP.SILVA %>% mutate(
  same = (SILVA_Genus %>% str_sub(
    start = + 1,
    end = -1L)) ==
    (RDP_Genus %>% str_sub(
      start = + 1,
      end = -1L))
)

#put row names back in and remove additional column - done now as pervious command removes row names

rownames(tax.RDP.SILVA) <- tax.RDP.SILVA[['ASV']] # put back rownames as rownames
tax.RDP.SILVA <- tax.RDP.SILVA[-1]#removes additional column created

#%ASVs classified consistantly. 

noASVsconsistantlyassigned <- table(tax.RDP.SILVA$same)["TRUE"] #221 - for the top 100 ASVs, 58% of the assignments are a match - explains the consistancy between the methods at a high level and gives comfort over this process and database consistancy. 

#proportion

PropASVsconsistantlyassigned <- 221/4400 #5%. These will be all be high confidence assigments. 

#Count no unclassified ASVs for RDP

ASVnogenusRDP <- tax.RDP.SILVA$RDP_Genus[grep("uncl", tax.RDP.SILVA$RDP_Genus)] #list ASVs with uncl = unclassifed somewhere in genus col - no genus ID
no.ASVnogenusRDP <- length(ASVnogenusRDP) #2479

#either use this vector to subset (egOTU.Dada2.only <- otu_table(ps)[(ASVsinDada2), ]) for example - or add a new T/F column to the table as below

tax.RDP.SILVA2 <- transform(tax.RDP.SILVA, ASVunassRDP = ifelse(
  grepl("uncl", tax.RDP.SILVA$RDP_Genus), "TRUE", "FALSE"))

#count no unclassified ASVs for SILVA

ASVnogenusSILVA <- tax.RDP.SILVA$SILVA_Genus[grep("uncl", tax.RDP.SILVA$SILVA_Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenusSILVA <- length(ASVnogenusSILVA) #1681 #more unclassified in RDP as expected as it's a smaller datebase.

#add a new T/F column to the results table

tax.RDP.SILVA3 <- transform(tax.RDP.SILVA2, ASVunassSILVA = ifelse(
  grepl("uncl", tax.RDP.SILVA$SILVA_Genus), "TRUE", "FALSE"))

#add column for confidence

tax.RDP.SILVA3$Confidence <- ifelse(tax.RDP.SILVA3$same %in% "TRUE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "High",
                              ifelse(tax.RDP.SILVA3$same %in% "TRUE" & tax.RDP.SILVA3$ASVunassRDP %in% "TRUE" & tax.RDP.SILVA3$ASVunassSILVA %in% "TRUE", "NA as unassigned",
                                     ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "Medium",
                                            ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "TRUE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "Low",
                                                   ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "TRUE", "Low", "NA as unassigned"))))      )

#Count how many ASVs are unassigned now

ASVs.Unass.BothDB <- tax.RDP.SILVA3$Confidence[grep("NA", tax.RDP.SILVA3$Confidence)] #1011 - 670 more asignmnets using both DBs than the best one (SILVA) alone AND at the same or greater confidence

#add column for database to use for assigment


tax.RDP.SILVA3$Database <- ifelse(tax.RDP.SILVA3$same %in% "TRUE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "SILVA",
                           ifelse(tax.RDP.SILVA3$same %in% "TRUE" & tax.RDP.SILVA3$ASVunassRDP %in% "TRUE" & tax.RDP.SILVA3$ASVunassSILVA %in% "TRUE", "RDP",
                           ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "RDP",
                           ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "TRUE" & tax.RDP.SILVA3$ASVunassSILVA %in% "FALSE", "SILVA",
                           ifelse(tax.RDP.SILVA3$same %in% "FALSE" & tax.RDP.SILVA3$ASVunassRDP %in% "FALSE" & tax.RDP.SILVA3$ASVunassSILVA %in% "TRUE", "RDP", "SILVA")))))

#add chosen taxonomy on to the OTU based on the tax database specified in the Database col.

tax.RDP.SILVA3$Domain <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Domain), paste(tax.RDP.SILVA3$SILVA_Domain)) 
tax.RDP.SILVA3$Phylum <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Phylum), paste(tax.RDP.SILVA3$SILVA_Phylum)) 
tax.RDP.SILVA3$Class <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Class), paste(tax.RDP.SILVA3$SILVA_Class)) 
tax.RDP.SILVA3$Order <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Order), paste(tax.RDP.SILVA3$SILVA_Order)) 
tax.RDP.SILVA3$Family <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Family), paste(tax.RDP.SILVA3$SILVA_Family)) 
tax.RDP.SILVA3$Genus <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Genus), paste(tax.RDP.SILVA3$SILVA_Genus)) 
tax.RDP.SILVA3$Species <- ifelse(tax.RDP.SILVA3$Database %in% "RDP", paste(tax.RDP.SILVA3$RDP_Species), paste(tax.RDP.SILVA3$SILVA_Species)) 

#recheck unassigned genera

ASVs.Unass.Both <- tax.RDP.SILVA3$Genus[grep("uncl", tax.RDP.SILVA3$Genus)] #same as above 

#Taxonomy with confidence,

Tax.conf <- tax.RDP.SILVA3[17:25]

# and a simple tax table for bringing into phyloseq. It needs a matrix.
tax.bb.ps <- Tax.conf[-c(1,2)]
tax.bb.ps2 <- as.matrix(tax.bb.ps)

#Remake a phyloseqobject for further analysis

USEARCHOTU.table <- read.csv("zotutab_raw.csv", header = TRUE, sep=",", row.names = 1)
metadata <- read.csv("~/Documents/PhD sample data/ParksMetadata16S.csv", sep=",", header=TRUE, row.names = 1)

library(Biostrings)
reference_seqs <- readDNAStringSet(file = "zotus.fa",
                                   format = "fasta", nrec = -1L, skip = 0L, seek.first.rec = FALSE, use.names = TRUE)

SEQ <- refseq(reference_seqs)
OTU = otu_table(USEARCHOTU.table, taxa_are_rows = TRUE) 
TAX = tax_table(tax.bb.ps2)
MET = sample_data(metadata)

ps.TU <- phyloseq(OTU, TAX, MET, SEQ)

#save new correct phyloseq object for ongoing use

save(ps.TU, file = "Parks16SUSEARCHBBPS1905.Rda")

#save workspace

save.image("~/Desktop/Parks16S/USEARCH/Parks16SUSEARCHBBs1905.RData")

