#######################################################################################################################################################################
######################################### R script to db-RDA with variance partioning and all other 16S parks data analysis ###########################################
#######################################################################################################################################################################

#Set working directory
setwd("~/Desktop/Parks16S")

#Load packages
library(vegan)
library(phyloseq)
library(ggplot2)
library(dplyr)
library(hillR)
library(goeveg)

#Load updated metadata - with trajectories, without controls (not present in decontaminated phyloseq object either)
load("16SParksmetadata.Rda")

#Prepare metadata for further analysis
#Remove redundanct or incomplete variables (particle count, wind speed, wind direction- cluster used instead, time, date)
Sample.data.final <- Sample.data.final[-c(12:14, 15)] #has none of the empty sites - check this is what we want to start with for the curated code - probably  not..might want Sample.data.A instead

#standardise (using zscores) numerical variables
Sample.data.final$Park.area.z <- scale(Sample.data.final$Park.area..m2., center = TRUE, scale = TRUE)
Sample.data.final$Elevation.z  <- scale(Sample.data.final$Elevation.sample.point..m.above.sea.level., center = TRUE, scale = TRUE)
Sample.data.final$Dist.sea.z  <- scale(Sample.data.final$Shortest.dist.to.sea...km., center = TRUE, scale = TRUE)
Sample.data.final$Temp.z  <- scale(Sample.data.final$Temp..oC., center = TRUE, scale = TRUE)
Sample.data.final$Humidity.z  <- scale(Sample.data.final$Humidity...., center = TRUE, scale = TRUE)

#remove unneeded colums with origonal numerical variables
Sample.data.final <- Sample.data.final[c(1:2, 10:16)]

#Remove Aotea square and rural location - reference samples not needed for most analysis - don't relate to 9 Auckland parks selected for central hypotheses testing
Sample.data.final  <- Sample.data.final  %>% Sample.data.final (Location !="Aotea Square " & Location!="Rural location")

#Reorder ascending by 16S sample number to ensure all data is matched in later analyses
Sample.data.final  <- Sample.data.final%>% arrange(Sample)
Sample.data.final.56 <- Sample.data.final%>% slice(c(1:35, 37:57)) #Take out empty site that will disrupt Hills nos (richness) bases analysis 

#Load decontaminated phyloseq object
load("USEARCH/PS16SParksDecontam1905.Rda")

# Hellinger-transform the OTU table
OTU.table <- as.data.frame(otu_table(ps.TUdecon))#pull OTU table out of phyloseq object for manipulation
OTU.hel <- decostand(OTU.table, "hellinger") #apply Hellinger transformation - deals with large numbers of 0s in dataset

#transpose OTU table so it has the same number of rows as the sample data
OTU.hel <- as.data.frame(t(OTU.hel))

#Correct no of rows of the OTU table (need to match - removal of Aotea sq and rural location in metadata needs to be reflected in OTU table)
OTU.hel <- OTU.hel%>% slice(c(6:37, 44:68)) #Samples from Aotea square/Rural location - KA118, KA119, KA120, KA224, KA232, KA116, KA121, KA230, KA231, KA243, KA269. These are in rows no 1, 2, 3, 4, 5, 38, 39, 40, 41, 42, 43

#reorder so OTU table data matches metadata
OTU.hel <- OTU.hel[sort(rownames(OTU.hel)),] 

#Make distance matrix with the OTU table - non transformed, with Bray-curtis distances
OTU.table2 <- as.data.frame(t(OTU.table))#transpose
OTU.table3 <- OTU.table2%>% slice(c(6:37, 44:68))#remove Aotea square/rural location
OTU.table3 <- OTU.table3[sort(rownames(OTU.table3)),] #reorder

#Create bray-curtis distance matrix for comparison non-compositional db-RDA
BD.dist <- as.matrix(vegdist(OTU.table3, "bray", binary = FALSE, diag = FALSE, upper = FALSE))

#calculate richness from modified OTU table OTU.table3 using hills nos
Hills.Nos <- Sample.data.final
Hills.Nos$D0 <- hill_taxa(comm = OTU.table3, q = 0, MARGIN = 1, base = exp(1)) #calculate Hills no D0 (raw richness)
Hills.Nos$D1 <- hill_taxa(comm = OTU.table3, q = 1, MARGIN = 1, base = exp(1)) #calculate Hills no D1
Hills.Nos$D2 <- hill_taxa(comm = OTU.table3, q = 2, MARGIN = 1, base = exp(1)) #calulate Hills no D2
Hills.Nos <- Hills.Nos[-(1:9)] #remove uneeded columns
Hills.Nos2 <- Hills.Nos%>% slice(c(1:35, 37:57)) #inf in KA228 - remove that site - empty and will distrupt later analysis

#Create filtered OTU table (raw read count over 100, coefficient of variability greater than 3), use OTUtable.3 without Aotea sq/rural location - that has the 57 observations in it.
OTU.table.F <- as.data.frame(t(OTU.table3)) #transpose
OTU.table.F$coefficient.var <- apply(OTU.table.F,1,cv, na.rm = TRUE) #add column with coefficient of variability (CV)
OTU.table.F$Total.abundance <- apply(OTU.table.F[1:57],1,sum, na.rm = TRUE) #add column with total abundace
OTU.table.F <- OTU.table.F%>% filter(Total.abundance>=100) #filter out ASVs with under 100 reads
OTU.table.F <- OTU.table.F%>% filter(coefficient.var>3) #filter out ASVs with CV under 3
OTU.table.F <- OTU.table.F[-c(58:59)] #Remove additional cols no longer needed
OTU.table.F <- as.data.frame(t(OTU.table.F)) #transpose

#hellinger transform filtered OTU table
OTU.hel.F <- decostand(OTU.table.F, "hellinger") 

#Make new BC matrix from filtered OTU table
BD.dist.F <- as.matrix(vegdist(OTU.table.F, "bray", binary = FALSE, diag = FALSE, upper = FALSE)) #some NaN  - need renoval
BD.dist.F[is.na(BD.dist.F)] <- 1 #Remove the NaN - replace with a 1 (as for the 5 or so times it happens, the rest of the values are all 1)

#Import data with UTM co-ordinates for all sample locations
load("Distancedata2.Rda") #Distance data with 57 rows 
load("Distancedata4.Rda") #Distance data with 56 rows (site that has inf which upsets richenss RDA removed)

#Calculate euclidean distanc matrix to represent location variable that will be one partition in the db-RDA with variance partioning
Dist.data.E1 <- as.matrix(vegdist(Dist.data2, "euclidean", binary = FALSE, diag = FALSE, upper = FALSE)) # One with 57 rows for most RDAs
Dist.data.E2 <- as.matrix(vegdist(Dist.data4, "euclidean", binary = FALSE, diag = FALSE, upper = FALSE)) # One with 56 rows for Hills nos based RDAs

#Calculate Aitchison distance matrix on filtered and unfiltered OTU tables for compositional analysis
#transform 0s - unfiltered
#calculate Aitchison matrix - unfiltered
#transform 0s - filtered
#calculate Aitchison matrix - filtered

############################################# RDA with var part for different wind trajectory lengths ################################################################
##Compositional methods##
  

##Non-compositional methods##
#Var part with hellinger transformed, unfiltered OTU table
Varpart.hel.W <- varpart(OTU.hel3, Sample.data.wT157[,10], Sample.data.wT157[,11], Sample.data.wT157[,4]) #Lots of collinerality detected
plot(Varpart.hel.W, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #Wind 3 day most informative 0.01

#Try with BC matrix on unfiltered OTU table
Varpart.BC.W <- varpart(BD.dist, Sample.data.wT157[,10], Sample.data.wT157[,11], Sample.data.wT157[,4]) #Lots of collinerality detected
plot(Varpart.BC.W, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #wind 3 day - 0.19, and 1 week is 0.02, residulas 0.81 - much better and makes more sense!

#With hellinger transformed filtered OTU table (reads over 100 and CV over 3)
Varpart.hel.WF <- varpart(OTU.hel.F, Sample.data.wT157[,10], Sample.dta.wT157[,11], Sample.data.wT157[,4]) #Lots of collinerality detected
plot(Varpart.hel.WF, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #3 day most important 0.06

#Try with BC matrix on filtered OTU table
Varpart.BC.WF <- varpart(BD.dist.F2, Sample.data.wT157[,10], Sample.data.wT157[,11], Sample.data.wT157[,4]) #Lots of collinerality detected
plot(Varpart.BC.WF, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #3 day 0.05, 1 day is 0.01

#Re-do with richness - with 56 row distance matrix
Varpart.R.HillsD0W <- varpart(Hills.Nos2$D0, Sample.data.wT156[,10], Sample.data.wT156[,11], Sample.data.wT156[,4]) #Lots of collinerality detected
plot(Varpart.R.HillsD0W, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #wind 3 day/1 week interaction most important 0.02
Varpart.R.HillsD1W <- varpart(Hills.Nos2$D1, Sample.data.wT156[,10], Sample.data.wT156[,11], Sample.data.wT156[,4]) #Lots of collinerality detected
plot(Varpart.R.HillsD1W, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) #3 day wind 0.11
Varpart.R.HillsD2W <- varpart(Hills.Nos2$D2, Sample.data.wT156[,10], Sample.data.wT156[,11], Sample.data.wT156[,4]) #Lots of collinerality detected
plot(Varpart.R.HillsD2W, Xnames = c("Wind 1 day", "Wind 1 week", "Wind 3 day"), bg=2:5) # 3 day most important but interactions with 1 day and 1 week also relevant



