#Analysis of the differences between RDP and UNITE classifications for USEARCH ASVs
library(phyloseq)

#Set working directory
setwd("~/Desktop/ParksITS/USEARCH")

#Read in tax tables
library("RDPutils")
taxtab.UNITE <- as.data.frame(import_sintax_file("ITS.sintax.txt", confidence = 0.8))
taxtab.RDP <- as.data.frame(import_sintax_file("sintax.txt", confidence = 0.8))

#rename cols so each DB can be distingushed later on

colnames(taxtab.UNITE) <- paste("UNITE", colnames(taxtab.UNITE), sep = "_")
colnames(taxtab.RDP) <- paste("RDP", colnames(taxtab.RDP), sep = "_")

#Pull out a list of the Genus in each dataset

RDPGenus <- taxtab.RDP$RDP_Genus
UNITEGenus <- taxtab.UNITE$UNITE_Genus

#Make venn diagram

library(VennDiagram)

venn.plot <- venn.diagram(
  x = list(
    "RDP Genera" = RDPGenus,
    "UNITE Genera" = UNITEGenus
  ),
  filename = "RDPvUNITEITSGeneraforpub.png",
  lwd = 4,
  fill = c("cornflowerblue", "darkorchid1"),
  alpha = 0.75,
  label.col = "deeppink3",
  cex = 3,
  imagetype = "png",
  fontfamily = "serif",
  fontface = "bold",
  cat.col = c("cornflowerblue", "darkorchid1"),
  cat.cex = 2,
  cat.fontfamily = "serif",
  cat.fontface = "bold",
  cat.dist = c(0.03, 0.03),
  cat.pos = c(-20, 14),
  resolution = 300
); #totals agree to above

#move ASV names into first column so they can be accessed by the join function
library(tibble)
taxtab.UNITE <- rownames_to_column(taxtab.UNITE, "ASV")
taxtab.RDP <- rownames_to_column(taxtab.RDP, "ASV")

#left join two files
library(dplyr)
tax.RDP.UNITE <- left_join(taxtab.UNITE, taxtab.RDP, by = "ASV")

#flag same or different classification at the Genus level - creates a new column "same" with true or false if the genus for each taxonomy database match.

library(tidyverse)
tax.RDP.UNITE <- tax.RDP.UNITE %>% mutate(
  same = (UNITE_Genus %>% str_sub(
    start = + 1,
    end = -1L)) ==
    (RDP_Genus %>% str_sub(
      start = + 1,
      end = -1L))
)

#put row names back in and remove additional column - done now as previous command removes row names

rownames(tax.RDP.UNITE) <- tax.RDP.UNITE[['ASV']] # put back rownames as rownames
tax.RDP.UNITE <- tax.RDP.UNITE[-1]#removes additional column created

#%ASVs classified consistantly.

noASVsconsistantlyassigned <- table(tax.RDP.UNITE$same)["TRUE"] #1708
#proportion
PropASVsconsistantlyassigned <- 1708/5519 #31%. These will be all be high confidence assigments. 

#Count no unclassified ASVs for RDP

ASVnogenusRDP <- tax.RDP.UNITE$RDP_Genus[grep("uncl", tax.RDP.UNITE$RDP_Genus)] #list ASVs with uncl = unclassifed somewhere in genus col - no genus ID
no.ASVnogenusRDP <- length(ASVnogenusRDP) #3899

#either use this vector to subset (egOTU.Dada2.only <- otu_table(ps)[(ASVsinDada2), ]) for example - or add a new T/F column to the table as below

tax.RDP.UNITE2 <- transform(tax.RDP.UNITE, ASVunassRDP = ifelse(
  grepl("uncl", tax.RDP.UNITE$RDP_Genus), "TRUE", "FALSE"))

#count no unclassified ASVs for UNITE

ASVnogenusUNITE <- tax.RDP.UNITE$UNITE_Genus[grep("uncl", tax.RDP.UNITE$UNITE_Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenusUNITE <- length(ASVnogenusUNITE) #3559 #more unclassified in RDP as expected as it's a smaller datebase.

#add a new T/F column to the results table

tax.RDP.UNITE3 <- transform(tax.RDP.UNITE2, ASVunassUNITE = ifelse(
  grepl("uncl", tax.RDP.UNITE2$UNITE_Genus), "TRUE", "FALSE"))

#add column for confidence

tax.RDP.UNITE3$Confidence <- ifelse(tax.RDP.UNITE3$same %in% "TRUE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "High",
                              ifelse(tax.RDP.UNITE3$same %in% "TRUE" & tax.RDP.UNITE3$ASVunassRDP %in% "TRUE" & tax.RDP.UNITE3$ASVunassUNITE %in% "TRUE", "NA as unassigned",
                                 ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "Medium",
                                     ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "TRUE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "Low",
                                        ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "TRUE", "Low", "NA as unassigned"))))      )

#Count how many ASVs are unassigned now

ASVs.Unass.BothDB <- tax.RDP.UNITE3$Confidence[grep("NA", tax.RDP.UNITE3$Confidence)] #2871 - 688 more asignmnets using both DBs than the best one (UNITE)

#add column for database to use for assigment 

tax.RDP.UNITE3$Database <- ifelse(tax.RDP.UNITE3$same %in% "TRUE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "RDP",
                                    ifelse(tax.RDP.UNITE3$same %in% "TRUE" & tax.RDP.UNITE3$ASVunassRDP %in% "TRUE" & tax.RDP.UNITE3$ASVunassUNITE %in% "TRUE", "RDP",
                                           ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "RDP",
                                                  ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "TRUE" & tax.RDP.UNITE3$ASVunassUNITE %in% "FALSE", "UNITE",
                                                         ifelse(tax.RDP.UNITE3$same %in% "FALSE" & tax.RDP.UNITE3$ASVunassRDP %in% "FALSE" & tax.RDP.UNITE3$ASVunassUNITE %in% "TRUE", "RDP", "RDP"))))      )


#add chosen taxonomy on to the OTU based on the tax database specified in the Database col.

tax.RDP.UNITE3$Domain <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Domain), paste(tax.RDP.UNITE3$UNITE_Domain)) 
tax.RDP.UNITE3$Phylum <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Phylum), paste(tax.RDP.UNITE3$UNITE_Phylum)) 
tax.RDP.UNITE3$Class <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Class), paste(tax.RDP.UNITE3$UNITE_Class)) 
tax.RDP.UNITE3$Order <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Order), paste(tax.RDP.UNITE3$UNITE_Order)) 
tax.RDP.UNITE3$Family <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Family), paste(tax.RDP.UNITE3$UNITE_Family)) 
tax.RDP.UNITE3$Genus <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Genus), paste(tax.RDP.UNITE3$UNITE_Genus)) 
tax.RDP.UNITE3$Species <- ifelse(tax.RDP.UNITE3$Database %in% "RDP", paste(tax.RDP.UNITE3$RDP_Species), paste(tax.RDP.UNITE3$UNITE_Species)) 

#recheck unassigned genera

ASVs.Unass.Both <- tax.RDP.UNITE3$Genus[grep("uncl", tax.RDP.UNITE3$Genus)] #same as above 

#Taxonomy with confidence,

Tax.conf <- tax.RDP.UNITE3[18:26]

# and a simple tax table for bringing into phyloseq. It needs a matrix.
tax.bb.ps <- Tax.conf[-c(1,2)]
tax.bb.ps2 <- as.matrix(tax.bb.ps)

#Remake a phyloseqobject for further analysis

USEARCHOTU.table <- read.csv("zotutab_raw.csv", header = TRUE, sep=",", row.names = 1)
metadata <- read.csv("~/Documents/PhD sample data/ParksMetadataITS.csv", sep=",", header=TRUE, row.names = 1)

library(Biostrings)
reference_seqs <- readDNAStringSet(file = "zotusITS.fa",
                                   format = "fasta", nrec = -1L, skip = 0L, seek.first.rec = FALSE, use.names = TRUE)

SEQ <- refseq(reference_seqs)
OTU = otu_table(USEARCHOTU.table, taxa_are_rows = TRUE) 
TAX = tax_table(tax.bb.ps2)
MET = sample_data(metadata)

ps.TU <- phyloseq(OTU, TAX, MET, SEQ)

#save new correct phyloseq object for ongoing use

save(ps.TU, file = "ParksITSUSEARCHBBPS1905.Rda")

#save workspace

save.image("~/Desktop/ParksITS/USEARCH/ParksITSUSEARCHBB1905.RData")





